@@ -1,9 +1,11 @@
-use crate::clock::Slot;
-use bincode::Result;
-use serde::Serialize;
-use std::{
-    net::{IpAddr, Ipv4Addr, Ipv6Addr, SocketAddr},
-    {fmt, io},
+use {
+    crate::clock::Slot,
+    bincode::Result,
+    serde::Serialize,
+    std::{
+        fmt, io,
+        net::{IpAddr, Ipv4Addr, Ipv6Addr, SocketAddr},
+    },
 };
 
 /// Maximum over-the-wire size of a Transaction
@@ -25,6 +27,7 @@ pub struct Meta {
     pub seed: [u8; 32],
     pub slot: Slot,
     pub is_tracer_tx: bool,
+    pub is_simple_vote_tx: bool,
 }
 
 #[derive(Clone)]
