@@ -1,12 +1,14 @@
-use itertools::Itertools;
-use solana_sdk::{
-    account::AccountSharedData,
-    instruction::{CompiledInstruction, Instruction, InstructionError},
-    keyed_account::{create_keyed_accounts_unified, KeyedAccount},
-    pubkey::Pubkey,
-    sysvar::Sysvar,
+use {
+    itertools::Itertools,
+    solana_sdk::{
+        account::AccountSharedData,
+        instruction::{CompiledInstruction, Instruction, InstructionError},
+        keyed_account::{create_keyed_accounts_unified, KeyedAccount},
+        pubkey::Pubkey,
+        sysvar::Sysvar,
+    },
+    std::{cell::RefCell, collections::HashSet, fmt::Debug, rc::Rc, sync::Arc},
 };
-use std::{cell::RefCell, collections::HashSet, fmt::Debug, rc::Rc, sync::Arc};
 
 /// Prototype of a native loader entry point
 ///
@@ -83,6 +85,8 @@ pub trait InvokeContext {
     /// Loaders may need to do work in order to execute a program.  Cache
     /// the work that can be re-used across executions
     fn add_executor(&self, pubkey: &Pubkey, executor: Arc<dyn Executor>);
+    /// Cache an executor that has changed
+    fn update_executor(&self, pubkey: &Pubkey, executor: Arc<dyn Executor>);
     /// Get the completed loader work that can be re-used across executions
     fn get_executor(&self, pubkey: &Pubkey) -> Option<Arc<dyn Executor>>;
     /// Record invoked instruction
@@ -491,6 +495,7 @@ impl<'a> InvokeContext for MockInvokeContext<'a> {
         Rc::new(RefCell::new(self.compute_meter.clone()))
     }
     fn add_executor(&self, _pubkey: &Pubkey, _executor: Arc<dyn Executor>) {}
+    fn update_executor(&self, _pubkey: &Pubkey, _executor: Arc<dyn Executor>) {}
     fn get_executor(&self, _pubkey: &Pubkey) -> Option<Arc<dyn Executor>> {
         None
     }
